---
title: Observium adapter
---

import ReferenceLink from "../../src/components/Card";
import Tabs from '@theme/Tabs';
import TabItem from '@theme/TabItem';

<!-- vale off -->
## What is Observium?
<!-- vale on -->
<!-- vale off -->
Observium is a network monitoring platform that delivers auto-discovery, detailed performance metrics, and rich visualizations to help you effectively manage and optimize your network infrastructure.

## Sync directions supported

- Observium → Infrahub

:::info

Currently, the Observium adapter supports only **one-way synchronization** from Observium to Infrahub.
Syncing data back into Observium is not yet supported.

:::

:::warning Under Construction
:::
<!-- vale on -->